==> refcomp-entities-1.6-sources.jar: fr/inra/refcomp/entities/UnitDeptLinkHelper.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class UnitDeptLinkHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private UnitDeptLinkHelper() {// empty
}

    public static String getUnit(Wikitty wikitty) {
        String value = wikitty.getFieldAsWikitty(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT);
        return value;
}

    public static String setUnit(Wikitty wikitty, String unit) {
        String oldValue = getUnit(wikitty);
        wikitty.setField(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT, unit);
        return oldValue;
}

    public static String getDepartment(Wikitty wikitty) {
        String value = wikitty.getFieldAsWikitty(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT);
        return value;
}

    public static String setDepartment(Wikitty wikitty, String department) {
        String oldValue = getDepartment(wikitty);
        wikitty.setField(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT, department);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT);
            Object f2 = w2.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT);
            Object f2 = w2.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(UnitDeptLink.EXT_UNITDEPTLINK);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : UnitDeptLinkAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(UnitDeptLink.EXT_UNITDEPTLINK);
}

} //UnitDeptLinkHelper

==> refcomp-entities-1.7-sources.jar: fr/inra/refcomp/entities/UnitDeptLinkHelper.java <==
/*
 * #%L
 * Refcomp :: entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2010 - 2012 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class UnitDeptLinkHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private UnitDeptLinkHelper() {// empty
}

    public static String getUnit(Wikitty wikitty) {
        String value = wikitty.getFieldAsWikitty(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT);
        return value;
}

    public static String setUnit(Wikitty wikitty, String unit) {
        String oldValue = getUnit(wikitty);
        wikitty.setField(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT, unit);
        return oldValue;
}

    public static Unit getUnit(Wikitty wikitty, boolean exceptionIfNotLoaded) {
        Unit value = WikittyUtil.newInstance(Unit.class, wikitty.getFieldAsWikitty(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT, exceptionIfNotLoaded));
        return value;
}

    public static Unit setUnit(Wikitty wikitty, Unit unit) {
        Unit oldValue = getUnit(wikitty, false);
        wikitty.setField(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT, unit);
        return oldValue;
}

    public static String getDepartment(Wikitty wikitty) {
        String value = wikitty.getFieldAsWikitty(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT);
        return value;
}

    public static String setDepartment(Wikitty wikitty, String department) {
        String oldValue = getDepartment(wikitty);
        wikitty.setField(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT, department);
        return oldValue;
}

    public static Department getDepartment(Wikitty wikitty, boolean exceptionIfNotLoaded) {
        Department value = WikittyUtil.newInstance(Department.class, wikitty.getFieldAsWikitty(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT, exceptionIfNotLoaded));
        return value;
}

    public static Department setDepartment(Wikitty wikitty, Department department) {
        Department oldValue = getDepartment(wikitty, false);
        wikitty.setField(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT, department);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT);
            Object f2 = w2.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_UNIT);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT);
            Object f2 = w2.getFieldAsObject(UnitDeptLink.EXT_UNITDEPTLINK, UnitDeptLink.FIELD_UNITDEPTLINK_DEPARTMENT);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(UnitDeptLink.EXT_UNITDEPTLINK);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : UnitDeptLinkAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(UnitDeptLink.EXT_UNITDEPTLINK);
}

} //UnitDeptLinkHelper
